from distutils.core import setup

setup (
	name = 'wow_nester',
	version = '1.2.0',
	py_modules = ['wow_nester'],
	author = 'none',
	author_eamil = 'none',
	url = 'none',
	descriptiom = 'A simple printer of nested lists',
)
